#
# spec file for package python-macholib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-macholib
Version:        1.16.3
Release:        3.1
Summary:        Mach-O header analysis and editing
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ronaldoussoren/macholib/
Source:         https://files.pythonhosted.org/packages/source/m/macholib/macholib-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-altgraph >= 0.15
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module altgraph >= 0.15}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
macholib can be used to analyze and edit Mach-O headers, the executable
format used by Mac OS X.

It's typically used as a dependency analysis tool, and also to rewrite dylib
references in Mach-O headers to be @executable_path relative.

Though this tool targets a platform specific file format, it is pure python
code that is platform and endian independent.

%prep
%setup -q -n macholib-%{version}
sed -i -e '/^#!\//, 1d' macholib/macho_dump.py
sed -i -e '/^#!\//, 1d' macholib/macho_find.py
sed -i -e '/^#!\//, 1d' macholib/macho_standalone.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/macho_dump
%python_clone -a %{buildroot}%{_bindir}/macho_standalone
%python_clone -a %{buildroot}%{_bindir}/macho_find
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests are too much platform specific (?)
rm macholib_tests/test_{command_line,dyld}.py
%pytest

%pre
%python_libalternatives_reset_alternative macho_dump
%python_libalternatives_reset_alternative macho_standalone
%python_libalternatives_reset_alternative macho_find

%files %{python_files}
%doc README.rst doc/*.rst
%license doc/license.rst
%python_alternative %{_bindir}/macho_find
%python_alternative %{_bindir}/macho_standalone
%python_alternative %{_bindir}/macho_dump
%{python_sitelib}/macholib
%{python_sitelib}/macholib-%{version}*-info

%changelog
* Mon Jun  9 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Mon Jun  2 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.16:
  * Add ``allow_unknown_load_commands`` option to ``MachO`` and
    ```macholib.MachOHeader``.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.16.1
  * Added some new CPU subtype definitions
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 1.16
  * Add allow_unknown_load_commands option to MachO and ```macholib.MachOHeader``.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr  1 2020 pgajdos@suse.com
- version update to 1.14
  * Repository moved to GitHub
  * #32: Update the LC_NAMES table
  * #31: Add two new load commands introduced in macOS 10.15
  * #27: Missing describe method for build_version_command
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 16 2018 Todd R <toddrme2178@gmail.com>
- Update to 1.11
  * Add very hacky limited support for @loader_path. This is just
    enough to deal with extensions and dylibs found in Python
    binary wheels.
- Update to 1.10
  * #25: Add support for LC_NOTE and LC_BUILD_VERSION
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 1.9
  + Features:
  * Add definition for ``macholib.mach_o.reloc_type_generic``, which
    was used in code but never defined.
  * #22: Add LICENSE file
  * #23: Added "--help" option for "python -m macholib"
  * Added function ``macholib.MachO.lc_str_value`` which should
    help in decoding value of ``macholib.mach_o.lc_str``. Those
    values are offsets in the data of a load command, the function
    will return the actually value as a byte string.
  + Bug fixes:
  * Pull request #15: Fix typo in thread_command class
- Spec file cleanups
- Fix rpmlint issues
* Thu Oct 19 2017 toddrme2178@gmail.com
- Initial version
